@@ -9,3 +9,12 @@ class HttpResponseJson(HttpResponse):
         json_data = simplejson.dumps(data)
         super(HttpResponseJson, self).__init__(
             content=json_data, mimetype='application/json')
+
+
+def backurl(request, default='/'):
+    """
+    Return previous url from user's browser history using Referer
+    header or ``default`` as fallback value.
+    """
+
+    return request.META.get('HTTP_REFERER', None) or default
